From 85232f5ec56e37097146223d4b3841dc3bac4005 Mon Sep 17 00:00:00 2001
From: Bharath Rupireddy <bharath.rupireddyforpostgres@gmail.com>
Date: Tue, 20 Dec 2022 12:32:38 +0000
Subject: [PATCH v1] Rename pg_dissect_walfile_name() to
 pg_split_walfile_name()

---
 doc/src/sgml/func.sgml                       |  8 ++++----
 src/backend/access/transam/xlogfuncs.c       | 10 +++++-----
 src/include/catalog/pg_proc.dat              |  4 ++--
 src/test/regress/expected/misc_functions.out | 10 +++++-----
 src/test/regress/sql/misc_functions.sql      | 10 +++++-----
 5 files changed, 21 insertions(+), 21 deletions(-)

diff --git a/doc/src/sgml/func.sgml b/doc/src/sgml/func.sgml
index 1f63dc6dba..b1b742e4e0 100644
--- a/doc/src/sgml/func.sgml
+++ b/doc/src/sgml/func.sgml
@@ -26101,9 +26101,9 @@ LOG:  Grand total: 1651920 bytes in 201 blocks; 622360 free (88 chunks); 1029560
       <row>
        <entry role="func_table_entry"><para role="func_signature">
         <indexterm>
-         <primary>pg_dissect_walfile_name</primary>
+         <primary>pg_split_walfile_name</primary>
         </indexterm>
-        <function>pg_dissect_walfile_name</function> ( <parameter>file_name</parameter> <type>text</type> )
+        <function>pg_split_walfile_name</function> ( <parameter>file_name</parameter> <type>text</type> )
         <returnvalue>record</returnvalue>
         ( <parameter>segno</parameter> <type>numeric</type>,
         <parameter>timeline_id</parameter> <type>bigint</type> )
@@ -26172,13 +26172,13 @@ postgres=# SELECT * FROM pg_walfile_name_offset((pg_backup_stop()).lsn);
    </para>
 
    <para>
-    <function>pg_dissect_walfile_name</function> is useful to compute a
+    <function>pg_split_walfile_name</function> is useful to compute a
     <acronym>LSN</acronym> from a file offset and WAL file name, for example:
 <programlisting>
 postgres=# \set file_name '000000010000000100C000AB'
 postgres=# \set offset 256
 postgres=# SELECT '0/0'::pg_lsn + pd.segno * ps.setting::int + :offset AS lsn
-  FROM pg_dissect_walfile_name(:'file_name') pd,
+  FROM pg_split_walfile_name(:'file_name') pd,
        pg_show_all_settings() ps
   WHERE ps.name = 'wal_segment_size';
       lsn
diff --git a/src/backend/access/transam/xlogfuncs.c b/src/backend/access/transam/xlogfuncs.c
index 0a31837ef1..5c0ec0b662 100644
--- a/src/backend/access/transam/xlogfuncs.c
+++ b/src/backend/access/transam/xlogfuncs.c
@@ -437,16 +437,16 @@ pg_walfile_name(PG_FUNCTION_ARGS)
  * name.
  */
 Datum
-pg_dissect_walfile_name(PG_FUNCTION_ARGS)
+pg_split_walfile_name(PG_FUNCTION_ARGS)
 {
-#define PG_DISSECT_WALFILE_NAME_COLS 2
+#define PG_SPLIT_WALFILE_NAME_COLS 2
 	char	   *fname = text_to_cstring(PG_GETARG_TEXT_PP(0));
 	char	   *fname_upper;
 	char	   *p;
 	TimeLineID	tli;
 	XLogSegNo	segno;
-	Datum		values[PG_DISSECT_WALFILE_NAME_COLS] = {0};
-	bool		isnull[PG_DISSECT_WALFILE_NAME_COLS] = {0};
+	Datum		values[PG_SPLIT_WALFILE_NAME_COLS] = {0};
+	bool		isnull[PG_SPLIT_WALFILE_NAME_COLS] = {0};
 	TupleDesc	tupdesc;
 	HeapTuple	tuple;
 	char		buf[256];
@@ -482,7 +482,7 @@ pg_dissect_walfile_name(PG_FUNCTION_ARGS)
 
 	PG_RETURN_DATUM(result);
 
-#undef PG_DISSECT_WALFILE_NAME_COLS
+#undef PG_SPLIT_WALFILE_NAME_COLS
 }
 
 /*
diff --git a/src/include/catalog/pg_proc.dat b/src/include/catalog/pg_proc.dat
index 98d90d9338..5dead1a3b0 100644
--- a/src/include/catalog/pg_proc.dat
+++ b/src/include/catalog/pg_proc.dat
@@ -6374,11 +6374,11 @@
   prosrc => 'pg_walfile_name' },
 { oid => '8205',
   descr => 'sequence number and timeline ID given a wal filename',
-  proname => 'pg_dissect_walfile_name', provolatile => 's',
+  proname => 'pg_split_walfile_name', provolatile => 's',
   prorettype => 'record', proargtypes => 'text',
   proallargtypes => '{text,numeric,int8}', proargmodes => '{i,o,o}',
   proargnames => '{file_name,segno,timeline_id}',
-  prosrc => 'pg_dissect_walfile_name' },
+  prosrc => 'pg_split_walfile_name' },
 
 { oid => '3165', descr => 'difference in bytes, given two wal locations',
   proname => 'pg_wal_lsn_diff', prorettype => 'numeric',
diff --git a/src/test/regress/expected/misc_functions.out b/src/test/regress/expected/misc_functions.out
index 2907f779a7..e391bfef9e 100644
--- a/src/test/regress/expected/misc_functions.out
+++ b/src/test/regress/expected/misc_functions.out
@@ -619,24 +619,24 @@ SELECT count(*) > 0 AS ok FROM pg_control_system();
  t
 (1 row)
 
--- pg_dissect_walfile_name
-SELECT * FROM pg_dissect_walfile_name(NULL);
+-- pg_split_walfile_name
+SELECT * FROM pg_split_walfile_name(NULL);
  segno | timeline_id 
 -------+-------------
        |            
 (1 row)
 
-SELECT * FROM pg_dissect_walfile_name('invalid');
+SELECT * FROM pg_split_walfile_name('invalid');
 ERROR:  invalid WAL file name "invalid"
 SELECT segno > 0 AS ok_segno, timeline_id
-  FROM pg_dissect_walfile_name('000000010000000100000000');
+  FROM pg_split_walfile_name('000000010000000100000000');
  ok_segno | timeline_id 
 ----------+-------------
  t        |           1
 (1 row)
 
 SELECT segno > 0 AS ok_segno, timeline_id
-  FROM pg_dissect_walfile_name('ffffffFF00000001000000af');
+  FROM pg_split_walfile_name('ffffffFF00000001000000af');
  ok_segno | timeline_id 
 ----------+-------------
  t        |  4294967295
diff --git a/src/test/regress/sql/misc_functions.sql b/src/test/regress/sql/misc_functions.sql
index 0c3d75fd1a..78fb2dc5ea 100644
--- a/src/test/regress/sql/misc_functions.sql
+++ b/src/test/regress/sql/misc_functions.sql
@@ -230,10 +230,10 @@ SELECT count(*) > 0 AS ok FROM pg_control_init();
 SELECT count(*) > 0 AS ok FROM pg_control_recovery();
 SELECT count(*) > 0 AS ok FROM pg_control_system();
 
--- pg_dissect_walfile_name
-SELECT * FROM pg_dissect_walfile_name(NULL);
-SELECT * FROM pg_dissect_walfile_name('invalid');
+-- pg_split_walfile_name
+SELECT * FROM pg_split_walfile_name(NULL);
+SELECT * FROM pg_split_walfile_name('invalid');
 SELECT segno > 0 AS ok_segno, timeline_id
-  FROM pg_dissect_walfile_name('000000010000000100000000');
+  FROM pg_split_walfile_name('000000010000000100000000');
 SELECT segno > 0 AS ok_segno, timeline_id
-  FROM pg_dissect_walfile_name('ffffffFF00000001000000af');
+  FROM pg_split_walfile_name('ffffffFF00000001000000af');
-- 
2.34.1

